@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -28,7 +28,7 @@ public:
      * @brief language
      * @return specified language
      */
-    Q_REQUIRED_RESULT QString language() const;
+    [[nodiscard]] QString language() const;
 
     /**
      * @brief setLanguage
